--[[ **LOCALIZATION SCRIPTS** ]]

-- Localization Ids used for localization lookups
LocId_Story_Friend = 1
LocId_Story_Badass = 2
LocId_Story_Joker = 3
LocId_Story_Psycho = 4
LocId_Story_Mascot = 5
LocId_Story_Knight = 6
LocId_Story_Vamp = 7
LocId_Story_Doc = 8
LocId_Story_Diva = 9
LocId_Story_Coach = 10

LocalizationData = {}

--[[ ** English Defaults ** ]]
-- individual languages should override in language specific files.

local GenderData =
{
	Male = {
		Gender = "Char_Gender_Male",
		PronounSub = "Char_PronounSub_Male",
		PronounObj = "Char_PronounObj_Male",
		PronounPos = "Char_PronounPos_Male",
		PronounPos2 = "Char_PronounPos2_Male",
		PronounSubC = "Char_PronounSubC_Male",
		PronounObjC = "Char_PronounObjC_Male",
		PronounPosC = "Char_PronounPosC_Male",
		PronounPos2C = "Char_PronounPos2C_Male",
		PronounToBe = "Char_PronounToBeSingular",
		PronounToBePast = "Char_PronounToBePastSingular",
		PronounMark = "Char_PronounMarkSingular",
		PronounSubContraction = "Char_PronounSubContractionSingular",
		VerbPresentKnow = "Char_VerbToKnowPresentSingular",
		Lineage = "Lineage_Male",
		Parentage = "Parentage_Male",
		SiblingStatus = "Sibling_Male",
		MiscHonorific = "Misc_Honorific_Male",
		YouthName = "YouthName_Male",
		FormalTitle = "FormalTitle_Male",
	},

	Female = {
		Gender = "Char_Gender_Female",
		PronounSub = "Char_PronounSub_Female",
		PronounObj = "Char_PronounObj_Female",
		PronounPos = "Char_PronounPos_Female",
		PronounPos2 = "Char_PronounPos2_Female",
		PronounSubC = "Char_PronounSubC_Female",
		PronounObjC = "Char_PronounObjC_Female",
		PronounPosC = "Char_PronounPosC_Female",
		PronounPos2C = "Char_PronounPos2C_Female",
		PronounToBe = "Char_PronounToBeSingular",
		PronounToBePast = "Char_PronounToBePastSingular",
		PronounMark = "Char_PronounMarkSingular",
		PronounSubContraction = "Char_PronounSubContractionSingular",
		VerbPresentKnow = "Char_VerbToKnowPresentSingular",
		Lineage = "Lineage_Female",
		Parentage = "Parentage_Female",
		SiblingStatus = "Sibling_Female",
		MiscHonorific = "Misc_Honorific_Female",
		YouthName = "YouthName_Female",
		FormalTitle = "FormalTitle_Female",
	},

	Neuter = {
		Gender = "Char_Gender_X",
		PronounSub = "Char_PronounSub_X",
		PronounObj = "Char_PronounObj_X",
		PronounPos = "Char_PronounPos_X",
		PronounPos2 = "Char_PronounPos2_X",
		PronounSubC = "Char_PronounSubC_X",
		PronounObjC = "Char_PronounObjC_X",
		PronounPosC = "Char_PronounPosC_X",
		PronounPos2C = "Char_PronounPos2C_X",
		PronounToBe = "Char_PronounToBePlural",
		PronounToBePast = "Char_PronounToBePastPlural",
		PronounMark = "Char_PronounMarkPlural",
		PronounSubContraction = "Char_PronounSubContractionPlural",
		VerbPresentKnow = "Char_VerbToKnowPresentPlural",
		Lineage = "Lineage_X",
		Parentage = "Parentage_X",
		SiblingStatus = "Sibling_X",
		MiscHonorific = "Misc_Honorific_X",
		YouthName = "YouthName_X",
		FormalTitle = "FormalTitle_X",
	}
}

LocalizationData[LocId_Story_Friend] = GenderData.Male
LocalizationData[LocId_Story_Badass] = GenderData.Female
LocalizationData[LocId_Story_Joker] = GenderData.Male
LocalizationData[LocId_Story_Psycho] = GenderData.Female
LocalizationData[LocId_Story_Mascot] = GenderData.Male
LocalizationData[LocId_Story_Knight] = GenderData.Male
LocalizationData[LocId_Story_Vamp] = GenderData.Female
LocalizationData[LocId_Story_Doc] = GenderData.Male
LocalizationData[LocId_Story_Diva] = GenderData.Female

function GetItemGender( item )

	local lang = GetLanguage({ })
	local itemGenders = {
		de = {
			XPItem01 = "f", -- Weisheitsspur
			PermanentAuraItem = "n", -- Verstärktes Mondserum
			PermanentSpeedItem = "n", -- Verstärktes Sternenserum
			PermanentRespawnItem = "n", -- Verstärktes Sonnenserum
			PlusSpeedItem = "f", -- Rückenwindbrosche
			TemporaryAuraItem = "n", -- Mondserum
			TemporarySpeedItem = "n", -- Sternenserum
			TemporaryRespawnItem = "n", -- Sonnenserum
			RespecItem = "m", -- Schreiber-Schnupftabak
			HarvestedMushroom01 = "f", -- Schwarzkappe
			HarvestedPlant01 = "f", -- HarvestedPlant01 (German name?)
			HarvestedFruit01 = "f", -- Unterbeere
			SeaItem02 = "m", -- Sedimentfelsen
			SeaItem03 = "n", -- Wyrmfutter
			SeaItem04 = "p", -- Korallenstücke
			SeaItem05 = "n", -- Flaschenlose Post
			SeaItem06 = "p", -- Umberflossen-Eier
			SeaItem07 = "m", -- Seepilz
			SeaItem10 = "p", -- Untergegangene Andenken
			SeaItem12 = "n", -- Schiffswrack
			SeaItem13 = "p", -- Sturmkappen
			SeaItem15 = "p", -- Salztee
			SeaItem16 = "p", -- Tiefenaale
			Fuel_Swath1_Item01 = "f", -- Sonnendistel
			Fuel_Swath1_Item02 = "m", -- Golpilz
			Fuel_Swath2_Item01 = "m", -- Jomuers Schweif
			Fuel_Swath2_Item02 = "f", -- Schleierspindel
			Fuel_Swath3_Item01 = "n", -- Nasenblatt
			Fuel_Swath3_Item02 = "n", -- Pestknolle
			Fuel_Swath5_Item01 = "m", -- Sinktang
			Fuel_Swath5_Item02 = "m", -- Triefgrund
			Fuel_Swath6_Item01 = "f", -- Sturmblüte
			Fuel_Swath6_Item02 = "m", -- Triefgrund
			Fuel_Swath7_Item01 = "n", -- Aschenblatt
			Fuel_Swath7_Item02 = "m", -- Nachtschatten
			Fuel_Swath9_Item01 = "f", -- Prismanessel
			Fuel_Swath9_Item02 = "m", -- Mondgrund
			Fish_Common_01 = "m", -- Dungfisch
			Fish_Common_02 = "m", -- Glopgillen
			Fish_Common_03 = "f", -- Umberflosse
			Fish_Common_04 = "m", -- Rifffresser
			Fish_Common_05 = "m", -- Achtring
			Fish_Common_06 = "m", -- Keulenkopf
			Fish_Rare_01 = "m", -- Schwarzaugenkugelfisch
			Fish_Rare_02 = "m", -- Schlurfer (prev. Kleiner Schlurfer did not work in accusative)
			Fish_Rare_03 = "m", -- Flecken-Slurgh
			UniqueSmallItem01 = "p", -- Jomuers Fangzahn
			UniqueMediumItem01 = "p", -- Gols Armschutz
			UniqueLargeItem01 = "p", -- Soliams Horn
			UniqueMediumAltItem01 = "p", -- Khaylmers Fußring
			UniqueImpItem01 = "p", -- Ha’ubs Flügel
			UniqueTrailItem01 = "p", -- Ores’ Schuppe
			UniqueFlyingItem01 = "p", -- Triestas Feder
			UniqueTreeItem01 = "p", -- Lus Zweig
			UniqueMonsterItem01 = "p", -- Miliths Schwanz
			Junk_Parcel_01 = "n", -- Schlichtes Paket
			Junk_Parcel_02 = "p", -- Schuldigkeiten
			Junk_Flower_01 = "f", -- Schwarzblume
			Junk_Stash_01 = "p", -- Versteck von {$CharPsycho.ShortName}
			Loot_CliffsItem_01 = "m", -- Porenkristall
			Loot_UnderthicketItem_01 = "m", -- Borkenstreifen
			Loot_Swath03Item_01 = "m", -- Noxpilz
			Junk_Swath1_Item02 = "m", -- Schurkristall
			Junk_Swath1_Item03 = "p", -- Gossenkrebse
			Junk_Swath1_Item04 = "p", -- Fruchtbare Erde
			Junk_Swath1_Item05 = "n", -- Gebetspergament
			Junk_Swath2_Item01 = "m", -- Balkenpilz
			Junk_Swath2_Item03 = "p", -- Heulerköttel
			Junk_Swath2_Item04 = "n", -- Vergessenes Paket
			Junk_Swath2_Item05 = "m", -- Liebesbrief
			Junk_Swath3_Item01 = "f", -- Sumpfkappe
			Junk_Swath3_Item02 = "p", -- Grabsteine
			Junk_Swath3_Item04 = "m", -- Geistesstein
			Junk_Swath3_Item06 = "p", -- Verlorene Erbstücke
			Junk_Swath7_Item01 = "p", -- Feuerpilze
			Junk_Swath7_Item02 = "p", -- Geschmolzenes Glas
			Junk_Swath7_Item03 = "p", -- Feenmilben
			Junk_Swath7_Item04 = "n", -- Schachtelholz
			Junk_Swath8_Item03 = "p", -- Sclorian-Schlamm
			Junk_Swath8_Item06 = "p", -- Hinuntergespülte Schmuggelware
			Junk_Swath9_Item01 = "n", -- Gold-Alodiel
			Junk_Swath9_Item02 = "f", -- Glühende Scherbe
			Junk_Swath9_Item03 = "f", -- Bergpflaume
			Junk_Swath9_Item04 = "p", -- Uralte Runen
			Junk_Swath9_Item05 = "n", -- Eidschwur
			Junk_Swath9_Item06 = "f", -- Weggeworfene Antiquität
		}
	}

	if itemGenders[lang] ~= nil then
		return itemGenders[lang][item] or "m"
	end
	return "m"

end

function GetLocationGender( location )
	
	local lang = GetLanguage({ })
	local venueGenders = {

		de = {
			 --  Swath 01 Nodes 
			Swath_01_Arena_01 = "m", -- Kamm von Gol
			
			Player_Hometown = "m", -- Shivport
			Swath_01_Travel_01 = "f", -- Südliche Sandgrube
			Swath_01_Travel_02 = "f", -- Unterland-Prärie
			Swath_01_Travel_03 = "m", -- Hohlwurz
			Swath_01_Travel_08 = "m", -- Blumenteich
			
			Swath_01_Travel_04 = "f", -- Acerbia
			Swath_01_Travel_05 = "m", -- Berg Murr
			Swath_01_Travel_07 = "m", -- Loneford
			Swath_01_Travel_09 = "f", -- Wunschbrunnen
			Swath_01_Travel_10 = "m", -- Shunt
			Swath_01_Travel_11 = "m", -- Loneford
			Swath_01_Travel_12 = "m", -- Blancrest
			Swath_01_Travel_13 = "n", -- Mirth-Tal

			 --  Swath 02 Nodes 
			Swath_02_Arena_01 = "f", -- Quelle von Jomuer
			Swath_02_Arena_02 = "f", -- Halde von Ha’ub
			
			Swath_02_Travel_12 = "m", -- Köterhügel
			
			Swath_02_Travel_06 = "f", -- Käferdüne

			Swath_02_Travel_07 = "m", -- Klebeschwarm
			Swath_02_Travel_02 = "m", -- Fallflach
			
			Swath_02_Travel_10 = "m", -- Shunt
			Swath_02_Travel_05 = "m", -- Lecksand

			Swath_02_Travel_03 = "f", -- Moisteria
			Swath_02_Travel_08 = "m", -- Verdrießlicher Golf
			Swath_02_Travel_09 = "f", -- Glitzernde Bergkette
			Swath_02_Travel_11 = "m", -- Blutbach
			Swath_02_Travel_13 = "f", -- Czelics Kaschemme
			Swath_02_Travel_14 = "m", -- Gelbteich
			Swath_02_Travel_15 = "m", -- Quislough
			
			 --  Swath 03 Nodes - Swamp / Crone Land 
			Swath_03_Arena_01 = "f", -- Grube von Milithe
			
			Swath_03_Travel_03 = "n", -- Nihiland
			Swath_03_Travel_09 = "m", -- Kalter Graben
			Swath_03_Travel_01 = "m", -- Plaguemont
			Swath_03_Travel_06 = "n", -- Brachland
			
			Swath_03_Travel_02 = "m", -- Lower Plaguemont
			Swath_03_Travel_04 = "m", -- Sturmfelsen
			Swath_03_Travel_05 = "f", -- Außengrenze
			Swath_03_Travel_07 = "m", -- Hafen von Ha’ub
			Swath_03_Travel_08 = "f", -- Hustlunge
			Swath_03_Travel_10 = "n", -- Große Bertrude
			Swath_03_Travel_11 = "f", -- Wyrm-Gosse

			 --  Swath 04 Nodes - Water / Wyrm Land 
			Swath_04_Travel_01 = "f", -- Wyrm-Küste
			Swath_04_Travel_02 = "f", -- Ertrinkende Weite
			Swath_04_Travel_03 = "f", -- Kalte Strömung
			Swath_04_Travel_04 = "m", -- Kammkappen
			Swath_04_Travel_05 = "m", -- Rand des Unterlands
			Swath_04_Travel_06 = "f", -- Weitreichende Tiefen
			Swath_04_Travel_07 = "n", -- Pestwasser
			Swath_04_Travel_08 = "n", -- Äußeres Solis
			Swath_04_Travel_09 = "f", -- Scharfe Untiefen
			Swath_04_Travel_10 = "m", -- Untersee
			Swath_04_Travel_11 = "m", -- Krabbengraben

			 --  Swath 05 Nodes - Water, Cont. 
			Swath_05_Arena_01 = "m", -- Rumpf von Ores
			Swath_05_Travel_02 = "f", -- Sturmwand
			Swath_05_Travel_04 = "n", -- Westliches Nirgendwo
			Swath_05_Travel_05 = "n", -- Nördliches Nirgendwo
			Swath_05_Travel_06 = "m", -- Abgrund des Imperiums
			Swath_05_Travel_07 = "n", -- Östliches Nirgendwo
			Swath_05_Travel_08 = "m", -- Unterkönig-Pass
			Swath_05_Travel_09 = "m", -- Unergründlicher Graben
			Swath_05_Travel_10 = "m", -- Zerklüfteter Felsen
			Swath_05_Travel_11 = "m", -- Schaumsee
			Swath_05_Travel_12 = "n", -- Südliches Nirgendwo
			
			 --  Swath 06 Nodes - Water, Cont. 
			Swath_06_Arena_01 = "f", -- Insel Khaylmer
			Swath_06_Travel_01 = "n", -- Auge des Sturms
			Swath_06_Travel_02 = "f", -- Westliche Verwehung
			Swath_06_Travel_03 = "f", -- Östliche Verwehung
			Swath_06_Travel_04 = "m", -- Finstersee
			Swath_06_Travel_05 = "f", -- Scharfe Untiefe
			Swath_06_Travel_06 = "n", -- Barb-Riff

			 --  Swath 07 Nodes - Lava Pits + Forest / Harps + Saps Land 
			Swath_07_Arena_01 = "n", -- Nest von Triesta
			Swath_07_Arena_02 = "f", -- Lichtung Lu
			
			Swath_07_Travel_01 = "n", -- Schwarzes Gestade

			Swath_07_Travel_01B = "f", -- Fliegende Bucht
			
			Swath_07_Travel_05 = "f", -- Schwefelmähne
			Swath_07_Travel_02 = "f", -- Glasgipfel
			Swath_07_Travel_02B = "f", -- Flamburg
			Swath_07_Travel_03 = "m", -- Irrwald
			Swath_07_Travel_04 = "n", -- Graumoor
			Swath_07_Travel_04B = "n", -- Nadelfeld
			Swath_07_Travel_06A = "m", -- Verbrannter Hain
			Swath_07_Travel_06B = "f", -- Schlackenschneise
			Swath_07_Travel_06C = "n", -- Unterdickicht
			Swath_07_Travel_13 = "n", -- Nadelfeld
			Swath_07_Travel_13_Old = "m", -- Nadelfeld
			Swath_07_Travel_07 = "f", -- Schlackenschneise
			Swath_07_Travel_07_Old = "n", -- Cleaveland
			
			Swath_07_Travel_08 = "m", -- Flammensee
			Swath_07_Travel_09 = "m", -- Kochender Graben
			Swath_07_Travel_10 = "m", -- Sinkender Osten

			Swath_07_Travel_11 = "m", -- Holzwall
			Swath_07_Travel_12 = "n", -- Schuldholz

			 --  Swath 08 Nodes - River Crossing / 
			Swath_08_Travel_01 = "n", -- Stromabwärts
			Swath_08_Travel_02 = "f", -- Sclorian-Gestade
			Swath_08_Travel_03 = "m", -- Murr-Pass

			 --  Swath 09 Nodes - Mountains + Ascension / Demons Land 
			Swath_09_Arena_01 = "m", -- Wasserfall von Soliam
			Swath_09_Travel_01 = "m", -- Berg Alodiel
			Swath_09_Travel_02A = "m", -- Aufstieg des Kaisers
			Swath_09_Travel_02B = "m", -- Fall des Kaisers
			Swath_09_Travel_03A = "f", -- Tempelstraße
			Swath_09_Travel_03B = "f", -- Tempelzisterne
			Swath_09_Travel_04 = "n", -- Tor der Schreiber
			Swath_09_Travel_05 = "f", -- Mondscheinbucht
			Swath_09_Travel_06 = "m", -- Langweg
			Swath_09_Travel_07 = "n", -- Alodiels Herz
		},

		es = {
			Swath_01_Arena_01 = "m", -- Cerro de Gol
			
			Player_Hometown = "m", -- Puerto temblor
			Swath_01_Travel_01 = "f", -- Colinas de Arena del Sur
			Swath_01_Travel_02 = "f", -- Pradera de Bajorreverso
			Swath_01_Travel_03 = "f", -- Raíz hueca
			Swath_01_Travel_08 = "f", -- Laguna radiante
			
			Swath_01_Travel_04 = "f", -- Acerbia
			Swath_01_Travel_05 = "m", -- Monte Murr
			Swath_01_Travel_07 = "m", -- Vado Solitario
			Swath_01_Travel_09 = "m", -- Pozo Silbador
			Swath_01_Travel_10 = "m", -- Cerrón
			Swath_01_Travel_11 = "m", -- Vado Solitario
			Swath_01_Travel_12 = "f", -- Crestablanca
			Swath_01_Travel_13 = "m", -- Valle del Gozo

			--  Swath 02 Nodes 
			Swath_02_Arena_01 = "m", -- Manantial de Jomuer
			Swath_02_Arena_02 = "m", -- Túmulo de Ha'ub
			
			Swath_02_Travel_12 = "f", -- Colina de los Cánidos
			
			Swath_02_Travel_06 = "f", -- Duna de los Escarabajos

			Swath_02_Travel_07 = "f", -- Colamena
			Swath_02_Travel_02 = "f", -- Meseta Plana
			
			Swath_02_Travel_10 = "m", -- Cerrón
			Swath_02_Travel_05 = "f", -- Lengua de Arena

			Swath_02_Travel_03 = "f", -- Humedaria
			Swath_02_Travel_08 = "m", -- Golfo Sombrío
			Swath_02_Travel_09 = "m", -- Campo Brillante
			Swath_02_Travel_11 = "m", -- Arroyo Sangriento
			Swath_02_Travel_13 = "f", -- Zambullida de Czelic
			Swath_02_Travel_14 = "f", -- Charca Amarilla
			Swath_02_Travel_15 = "m", -- Quislago
			
			--  Swath 03 Nodes - Swamp / Crone Land 
			Swath_03_Arena_01 = "m", -- Abismo de Milithe
			
			Swath_03_Travel_03 = "f", -- Nihilandia
			Swath_03_Travel_09 = "f", -- Fosafría
			Swath_03_Travel_01 = "f", -- Monteplaga
			Swath_03_Travel_06 = "m", -- Campocaído
			
			Swath_03_Travel_02 = "f", -- Monteplaga de abajo
			Swath_03_Travel_04 = "f", -- Roca de las tempestades
			Swath_03_Travel_05 = "m", -- Límite Exterior
			Swath_03_Travel_07 = "m", -- Puerto de Ha'ub
			Swath_03_Travel_08 = "m", -- Pulmontós
			Swath_03_Travel_10 = "f", -- La casa de la Gran Bertrude
			Swath_03_Travel_11 = "m", -- Alcantarillagusano

			--  Swath 04 Nodes - Water / Wyrm Land 
			Swath_04_Travel_01 = "f", -- Costa Gusano
			Swath_04_Travel_02 = "m", -- Inmensidad de los Ahogados
			Swath_04_Travel_03 = "m", -- Arroyo Frío
			Swath_04_Travel_04 = "m", -- Olas Encrespadas
			Swath_04_Travel_05 = "m", -- Borde del Bajorreverso
			Swath_04_Travel_06 = "m", -- Sumas Profundidades
			Swath_04_Travel_07 = "f", -- Aguaplaga
			Swath_04_Travel_08 = "m", -- Solis Exterior
			Swath_04_Travel_09 = "m", -- Bancafilados
			Swath_04_Travel_10 = "m", -- Bajomar
			Swath_04_Travel_11 = "f", -- Posa Cangrejera

			--  Swath 05 Nodes - Water, Cont. 
			Swath_05_Arena_01 = "m", -- Pecio de Ores
			Swath_05_Travel_02 = "m", -- Tormentamuro
			Swath_05_Travel_04 = "m", -- Oeste de Ningún Lugar
			Swath_05_Travel_05 = "m", -- Norte de Ningún Lugar
			Swath_05_Travel_06 = "m", -- Abismo del Dominio
			Swath_05_Travel_07 = "m", -- Este de Ningún Lugar
			Swath_05_Travel_08 = "m", -- Paso Infrarrey
			Swath_05_Travel_09 = "f", -- Zanja Desbrazada
			Swath_05_Travel_10 = "f", -- Roca Dentada
			Swath_05_Travel_11 = "f", -- Mar de la Espuma
			Swath_05_Travel_12 = "m", -- Sur de Ningún Lugar
			
			--  Swath 06 Nodes - Water, Cont. 
			Swath_06_Arena_01 = "f", -- Isla de Khaylmer
			Swath_06_Travel_01 = "m", -- Ojo de la Tempestad
			Swath_06_Travel_02 = "m", -- Terrenos Occidentales
			Swath_06_Travel_03 = "m", -- Terrenos Orientales
			Swath_06_Travel_04 = "m", -- Mar de los Enojos
			Swath_06_Travel_05 = "m", -- Bancafilado
			Swath_06_Travel_06 = "m", -- Arrecife de la Barba

			--  Swath 07 Nodes - Lava Pits + Forest / Harps + Saps Land 
			Swath_07_Arena_01 = "m", -- Nido de Triesta
			Swath_07_Arena_02 = "m", -- Claro de Lu
			
			Swath_07_Travel_01 = "f", -- Orilla Negra

			Swath_07_Travel_01B = "f", -- Cala de Ala Alta
			
			Swath_07_Travel_05 = "m", -- Crin Sulfúrea
			Swath_07_Travel_02 = "m", -- Pico de Cristal
			Swath_07_Travel_02B = "m", -- Flamburgo
			Swath_07_Travel_03 = "m", -- Bosquevivo
			Swath_07_Travel_04 = "m", -- Páramo Gris
			Swath_07_Travel_04B = "m", -- Campo de Agujas
			Swath_07_Travel_06A = "f", -- Arboleda Quemada
			Swath_07_Travel_06B = "f", -- Raíz de Ceniza
			Swath_07_Travel_06C = "m", -- Bajomatorral
			Swath_07_Travel_13 = "m", -- Campo de Agujas
			Swath_07_Travel_13_Old = "m", -- Campo de Agujas
			Swath_07_Travel_07 = "f", -- Raíz de Ceniza
			Swath_07_Travel_07_Old = "f", -- Hendilandia
			
			Swath_07_Travel_08 = "m", -- Lago Incendiado
			Swath_07_Travel_09 = "f", -- Fosa Hirviente
			Swath_07_Travel_10 = "m", -- Este Sumiente

			Swath_07_Travel_11 = "m", -- Murobosque
			Swath_07_Travel_12 = "f", -- Corteza Oscura

			--  Swath 08 Nodes - River Crossing / 
			Swath_08_Travel_01 = "f", -- Ríoabajo
			Swath_08_Travel_02 = "f", -- Costa del Sclorian
			Swath_08_Travel_03 = "m", -- Paso de Murr

			--  Swath 09 Nodes - Mountains + Ascension / Demons Land 
			Swath_09_Arena_01 = "f", -- Cascada de Soliam
			Swath_09_Travel_01 = "m", -- Monte Alodiel
			Swath_09_Travel_02A = "m", -- Ascenso del Emperador
			Swath_09_Travel_02B = "f", -- Caída del Emperador
			Swath_09_Travel_03A = "f", -- Carretera del Templo
			Swath_09_Travel_03B = "f", -- Cisterna del Templo
			Swath_09_Travel_04 = "f", -- Puerta de los Escribas
			Swath_09_Travel_05 = "m", -- Nicho de la Luz de la Luna
			Swath_09_Travel_06 = "m", -- Camino largo
			Swath_09_Travel_07 = "m", -- Corazón de Alodiel
		}
	}

	if venueGenders[lang] ~= nil then
		return venueGenders[lang][location] or "m"
	end
	return "m"

end

function SetupCoachGender( gender )

	if gender == "m" then
		LocalizationData[LocId_Story_Coach] = GenderData.Male
	elseif gender == "n" then
		LocalizationData[LocId_Story_Coach] = GenderData.Neuter
	elseif gender == "f" then
		LocalizationData[LocId_Story_Coach] = GenderData.Female
	else
		DebugPrint({ Text = "Invalide gender, defaulting to female" })
		LocalizationData[LocId_Story_Coach] = GenderData.Female
	end

end

NeutralUnavailableLangs = ToLookup({ "fr", "es", "ru", "zh-CN", "de" })
NeutralOnlyLangs = ToLookup({ })

function ToggleGender()

	local lang = GetLanguage({ })
	if NeutralOnlyLangs[lang] then
		SetCoachNeutral()
		return
	end

	if not clickedGenderTooltipOnce and Coach.Gender ~= "Char_Gender_X" then
		clickedGenderTooltipOnce = true
		if Coach.Gender == "Char_Gender_Male" then
			rolledMale = true
			SetCoachFemale()
		elseif Coach.Gender == "Char_Gender_Female" then
			rolledFemale = true
			SetCoachMale()
		end
	elseif clickedGenderTooltipOnce and not clickedGenderTooltipTwice and Coach.Gender ~= "Char_Gender_X" and not NeutralUnavailableLangs[lang] then
		clickedGenderTooltipTwice = true
		SetCoachNeutral()
	else
		if rolledFemale then
			if Coach.Gender == "Char_Gender_X" then
				SetCoachFemale()
			elseif Coach.Gender == "Char_Gender_Female" then
				SetCoachMale()
			elseif Coach.Gender == "Char_Gender_Male" then
				if NeutralUnavailableLangs[lang] then
					SetCoachFemale()
				else
					SetCoachNeutral()
				end
			end
		else
			if Coach.Gender == "Char_Gender_X" then
				SetCoachMale()
			elseif Coach.Gender == "Char_Gender_Male" then
				SetCoachFemale()
			elseif Coach.Gender == "Char_Gender_Female" then
				if NeutralUnavailableLangs[lang] then
					SetCoachMale()
				else
					SetCoachNeutral()
				end
			end
		end
	end

end

function SetCoachFemale()
	Coach.Gender = "Char_Gender_Female"
	SetConfigOption({ Name = "CoachGender", Value = Coach.Gender })
	Coach.JokerNickName = "Coach_JokerNickName_Alt"
	Coach.PsychoNickName = "Coach_PsychoNickname_Female"
	Coach.DocNickName = "Coach_DocNickname_Female"
	Coach.BardNickName = "Coach_BardNickname_Female"
	SetFemalePronouns( Coach )
	introRukeyComment = "JokerIntroComment01"
	SetupCoachGender( "f" )
end

function SetCoachMale()
	Coach.Gender = "Char_Gender_Male"
	SetConfigOption({ Name = "CoachGender", Value = Coach.Gender })
	Coach.JokerNickName = "Coach_JokerNickName"
	Coach.PsychoNickName = "Coach_PsychoNickname_Male"
	Coach.DocNickName = "Coach_DocNickname_Male"
	Coach.BardNickName = "Coach_BardNickname_Male"
	SetMalePronouns( Coach )
	introRukeyComment = "JokerIntroComment01"
	SetupCoachGender( "m" )
end

function SetCoachNeutral()
	Coach.Gender = "Char_Gender_X"
	SetConfigOption({ Name = "CoachGender", Value = Coach.Gender })
	Coach.JokerNickName = "Coach_JokerNickName"
	Coach.PsychoNickName = "Coach_PsychoNickname_X"
	Coach.DocNickName = "Coach_DocNickname_X"
	Coach.BardNickName = "Coach_BardNickname_X"
	SetNeutralPronouns( Coach )
	introRukeyComment = "JokerIntroComment02"
	SetupCoachGender( "n" )
end

function SetMalePronouns( character )
	character.PronounSub = "Char_PronounSub_Male"
	character.PronounObj = "Char_PronounObj_Male"
	character.PronounPos = "Char_PronounPos_Male"
	character.PronounPos2 = "Char_PronounPos2_Male"
	character.PronounSubC = "Char_PronounSubC_Male"
	character.PronounObjC = "Char_PronounObjC_Male"
	character.PronounPosC = "Char_PronounPosC_Male"
	character.PronounPos2C = "Char_PronounPos2C_Male"
	character.PronounToBe = "Char_PronounToBeSingular"
	character.PronounToBePast = "Char_PronounToBePastSingular"
	character.PronounMark = "Char_PronounMarkSingular"
	character.PronounSubContraction = "Char_PronounSubContractionSingular"
	character.VerbPresentKnow = "Char_VerbToKnowPresentSingular"
	character.Lineage = "Lineage_Male"
	character.Parentage = "Parentage_Male"
	character.SiblingStatus = "Sibling_Male"
	character.YouthName = "YouthName_Male"
	character.FormalTitle = "FormalTitle_Male"
	character.MiscHonorific = "Misc_Honorific_Male"

	if GetLanguage({ }) == "de" then
		character.Pronoun1 = "Char_Pronoun1_Male"
		character.Pronoun2 = "Char_Pronoun2_Male"
		character.Pronoun3 = "Char_Pronoun3_Male"
		character.Pronoun4 = "Char_Pronoun4_Male"
		character.Pronoun5 = "Char_Pronoun5_Male"
		character.Pronoun6 = "Char_Pronoun6_Male"
		character.Pronoun7 = "Char_Pronoun7_Male"
		character.Pronoun8 = "Char_Pronoun8_Male"
	end
end

function SetFemalePronouns( character )
	character.PronounSub = "Char_PronounSub_Female"
	character.PronounObj = "Char_PronounObj_Female"
	character.PronounPos = "Char_PronounPos_Female"
	character.PronounPos2 = "Char_PronounPos2_Female"
	character.PronounSubC = "Char_PronounSubC_Female"
	character.PronounObjC = "Char_PronounObjC_Female"
	character.PronounPosC = "Char_PronounPosC_Female"
	character.PronounPos2C = "Char_PronounPos2C_Female"
	character.PronounToBe = "Char_PronounToBeSingular"
	character.PronounToBePast = "Char_PronounToBePastSingular"
	character.PronounMark = "Char_PronounMarkSingular"
	character.PronounSubContraction = "Char_PronounSubContractionSingular"
	character.VerbPresentKnow = "Char_VerbToKnowPresentSingular"
	character.Lineage = "Lineage_Female"
	character.Parentage = "Parentage_Female"
	character.SiblingStatus = "Sibling_Female"
	character.YouthName = "YouthName_Female"
	character.FormalTitle = "FormalTitle_Female"
	character.MiscHonorific = "Misc_Honorific_Female"

	if GetLanguage({ }) == "de" then
		character.Pronoun1 = "Char_Pronoun1_Female"
		character.Pronoun2 = "Char_Pronoun2_Female"
		character.Pronoun3 = "Char_Pronoun3_Female"
		character.Pronoun4 = "Char_Pronoun4_Female"
		character.Pronoun5 = "Char_Pronoun5_Female"
		character.Pronoun6 = "Char_Pronoun6_Female"
		character.Pronoun7 = "Char_Pronoun7_Female"
		character.Pronoun8 = "Char_Pronoun8_Female"
	end
end

function SetNeutralPronouns( character )
	character.PronounSub = "Char_PronounSub_X"
	character.PronounObj = "Char_PronounObj_X"
	character.PronounPos = "Char_PronounPos_X"
	character.PronounPos2 = "Char_PronounPos2_X"
	character.PronounSubC = "Char_PronounSubC_X"
	character.PronounObjC = "Char_PronounObjC_X"
	character.PronounPosC = "Char_PronounPosC_X"
	character.PronounPos2C = "Char_PronounPos2C_X"
	character.PronounToBe = "Char_PronounToBePlural"
	character.PronounToBePast = "Char_PronounToBePastPlural"
	character.PronounMark = "Char_PronounMarkPlural"
	character.PronounSubContraction = "Char_PronounSubContractionPlural"
	character.VerbPresentKnow = "Char_VerbToKnowPresentPlural"
	character.Lineage = "Lineage_X"
	character.Parentage = "Parentage_X"
	character.SiblingStatus = "Sibling_X"
	character.YouthName = "YouthName_X"
	character.FormalTitle = "FormalTitle_X"
	character.MiscHonorific = "Misc_Honorific_X"
end

function ReloadLocalizationData()

	if LocalizationData[LocId_Story_Coach] == nil and Coach ~= nil then

		local savedGender = GetConfigOptionValue({ Name = "CoachGender" })
		if savedGender ~= nil and savedGender ~= "" then
			Coach.Gender = savedGender
		end

		if Coach.Gender == "Char_Gender_Male" then
			SetCoachMale()
		elseif Coach.Gender == "Char_Gender_X" then
			SetCoachNeutral()
		elseif Coach.Gender == "Char_Gender_Female" then
			SetCoachFemale()
		else
			DebugPrint({ Text = "No gender set for coach, defaulting to female" })
			SetCoachFemale()
		end

	end

end

function OnLanguageChanged()

	if League == nil then
		return
	end

	for teamIndex, team in pairs( League ) do
		for characterIndex, character in pairs( team.TeamBench ) do
			SetupNames( character )
			SetupPronouns( character )
			SetupBirthday( character )
		end
	end

	for npcName, npc in pairs( NPCs ) do
		SetupPronouns( npc )
		SetupPortraits( npc )
		SetupBirthday( npc )
	end

end

OnAnyLoad{
	function( triggerArgs )
		local prevLang = StoredLang
		StoredLang = GetLanguage({ })
		PersistVariable({ Name = "StoredLang" })
		if prevLang ~= StoredLang then
			OnLanguageChanged()
		end
	end
}